==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_6_1/jsd_cdc0bafd4257e78d211a1f4120bfa9.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center AddMulticastVirtualNetworksV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCdc0BaFd4257E78D211A1F4120Bfa9(object):
    """AddMulticastVirtualNetworksV1 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorCdc0BaFd4257E78D211A1F4120Bfa9, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "fabricId": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "ipv4SsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "multicastRPs": {
                "items": {
                "properties": {
                "ipv4Address": {
                "type": "string"
                },
                "ipv4AsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "ipv6Address": {
                "type": "string"
                },
                "ipv6AsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "isDefaultV4RP": {
                "type": "boolean"
                },
                "isDefaultV6RP": {
                "type": "boolean"
                },
                "networkDeviceIds": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "rpDeviceLocation": {
                "enum": [
                "EXTERNAL",
                "FABRIC"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "virtualNetworkName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v3_1_3_0/jsd_cdc0bafd4257e78d211a1f4120bfa9.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center AddMulticastVirtualNetworks data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCdc0BaFd4257E78D211A1F4120Bfa9(object):
    """AddMulticastVirtualNetworks request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorCdc0BaFd4257E78D211A1F4120Bfa9, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "fabricId": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "ipv4SsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "multicastRPs": {
                "items": {
                "properties": {
                "ipv4Address": {
                "type": "string"
                },
                "ipv4AsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "ipv6Address": {
                "type": "string"
                },
                "ipv6AsmRanges": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "isDefaultV4RP": {
                "type": "boolean"
                },
                "isDefaultV6RP": {
                "type": "boolean"
                },
                "networkDeviceIds": {
                "items": {
                "type": "string"
                },
                "type": "array"
                },
                "rpDeviceLocation": {
                "enum": [
                "EXTERNAL",
                "FABRIC"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "virtualNetworkName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
